George
======

**Fast and flexible Gaussian Process regression in Python.**

.. image:: https://img.shields.io/badge/GitHub-dfm%2Fgeorge-blue.svg?style=flat
    :target: https://github.com/dfm/george
.. image:: http://img.shields.io/badge/license-MIT-blue.svg?style=flat
    :target: https://github.com/dfm/george/blob/main/LICENSE
.. image:: https://github.com/dfm/george/workflows/Tests/badge.svg?style=flat
    :target: https://github.com/dfm/george/actions?query=workflow%3ATests
.. image:: https://coveralls.io/repos/github/dfm/george/badge.svg?branch=main&style=flat
    :target: https://coveralls.io/github/dfm/george?branch=main
.. image:: https://readthedocs.org/projects/george/badge/?version=latest
    :target: http://george.readthedocs.io/en/latest/?badge=latest

Read the documentation at: `george.readthedocs.io <http://george.readthedocs.io/>`_.
